@@ -52,6 +52,7 @@ class Client(_ClientCore):  # pylint: disable=too-many-public-methods
 
         If you want something tailored to your use case, run your own loop that fetches the recent blockhash,
         and pass that value in your ``.send_transaction`` calls.
+    :param timeout: HTTP request timeout in seconds.
 
     """
 
@@ -60,10 +61,11 @@ class Client(_ClientCore):  # pylint: disable=too-many-public-methods
         endpoint: Optional[str] = None,
         commitment: Optional[Commitment] = None,
         blockhash_cache: Union[BlockhashCache, bool] = False,
+        timeout: float = 10,
     ):
         """Init API client."""
         super().__init__(commitment, blockhash_cache)
-        self._provider = http.HTTPProvider(endpoint)
+        self._provider = http.HTTPProvider(endpoint, timeout=timeout)
 
     def is_connected(self) -> bool:
         """Health check.
@@ -258,6 +260,63 @@ class Client(_ClientCore):  # pylint: disable=too-many-public-methods
         args = self._get_confirmed_block_args(slot, encoding)
         return self._provider.make_request(*args)
 
+    def get_block(
+        self,
+        slot: int,
+        encoding: str = "json",
+    ) -> types.RPCResponse:
+        """Returns identity and transaction information about a confirmed block in the ledger.
+
+        :param slot: Slot, as u64 integer.
+        :param encoding: (optional) Encoding for the returned Transaction, either "json", "jsonParsed",
+            "base58" (slow), or "base64". If parameter not provided, the default encoding is JSON.
+
+        >>> solana_client = Client("http://localhost:8899")
+        >>> solana_client.get_block(1) # doctest: +SKIP
+        {'jsonrpc': '2.0',
+         'result': {'blockTime': None, 'blockHeight': 0,
+          'blockhash': '39pJzWsPn59k2PuHqhB7xNYBNGFXcFVkXLertHPBV4Tj',
+          'parentSlot': 0,
+          'previousBlockhash': 'EwF9gtehrrvPUoNticgmiEadAWzn4XeN8bNaNVBkS6S2',
+          'rewards': [],
+          'transactions': [{'meta': {'err': None,
+             'fee': 0,
+             'postBalances': [500000000000, 26858640, 1, 1, 1],
+             'preBalances': [500000000000, 26858640, 1, 1, 1],
+             'status': {'Ok': None}},
+            'transaction': {'message': {'accountKeys': ['LjvEBM78ufAikBfxqtj4RNiAECUi7Xqtz9k3QM3DzPk',
+               'EKAar3bMQUZvGSonq7vcPF2nPaCYowbnat44FPafW8Po',
+               'SysvarS1otHashes111111111111111111111111111',
+               'SysvarC1ock11111111111111111111111111111111',
+               'Vote111111111111111111111111111111111111111'],
+              'header': {'numReadonlySignedAccounts': 0,
+               'numReadonlyUnsignedAccounts': 3,
+               'numRequiredSignatures': 1},
+              'instructions': [{'accounts': [1, 2, 3, 0],
+                'data': '37u9WtQpcm6ULa3VmTgTKEBCtYMxq84mk82tRvKdFEwj3rALiptAzuMJ1yoVSFAMARMZYp7q',
+                'programIdIndex': 4}],
+              'recentBlockhash': 'EwF9gtehrrvPUoNticgmiEadAWzn4XeN8bNaNVBkS6S2'},
+             'signatures': ['63jnpMCs7TNnCjnTqUrX7Mvqc5CbJMtVkLxBjPHUQkjXyZrQuZpfhjvzA7A29D9tMqVaiQC3UNP1NeaZKFFHJyQE']}}]},
+         'id': 9}
+        >>> solana_client.get_block(1, encoding="base64") # doctest: +SKIP
+        {'jsonrpc': '2.0',
+         'result': {'blockTime': None, 'blockHeight': 0,
+          'blockhash': '39pJzWsPn59k2PuHqhB7xNYBNGFXcFVkXLertHPBV4Tj',
+          'parentSlot': 0,
+          'previousBlockhash': 'EwF9gtehrrvPUoNticgmiEadAWzn4XeN8bNaNVBkS6S2',
+          'rewards': [],
+          'transactions': [{'meta': {'err': None,
+             'fee': 0,
+             'postBalances': [500000000000, 26858640, 1, 1, 1],
+             'preBalances': [500000000000, 26858640, 1, 1, 1],
+             'status': {'Ok': None}},
+            'transaction': ['AfxyKHmHIjXWjkyHODGeAbVxmfQWPj1ydS9nF+ynJHo8I1vCPDp2P9Cj5aA6W1CAHEHCqY0B1FDKomCzRo3qrAsBAAMFBQ6QBWfhQF7rG02xhuEsmmrUtz3AUjBtJKkqaHPJEmvFzziDX0C0robPrl9RbOyXHoc9/Dxa0zoGL6cEjvCjLgan1RcZLwqvxvJl4/t3zHragsUp0L47E24tAFUgAAAABqfVFxjHdMkoVmOYaR1etoteuKObS21cc1VbIQAAAAAHYUgdNXR0u3xNdiTr072z2DVec9EQQ/wNo1OAAAAAAM8NSv7ISDPN9E9XNL9vX7h8LuJHWlopUcX39DxsDx23AQQEAQIDADUCAAAAAQAAAAAAAAAAAAAAAAAAAIWWp5Il3Kg312pzVk6Jt61iyFhTbtmkh/ORbj3JUQRbAA==',
+             'base64']}]},
+         'id': 10}
+        """  # noqa: E501 # pylint: disable=line-too-long
+        args = self._get_block_args(slot, encoding)
+        return self._provider.make_request(*args)
+
     def get_confirmed_blocks(self, start_slot: int, end_slot: Optional[int] = None) -> types.RPCResponse:
         """Returns a list of confirmed blocks.
 
@@ -271,6 +330,19 @@ class Client(_ClientCore):  # pylint: disable=too-many-public-methods
         args = self._get_confirmed_blocks_args(start_slot, end_slot)
         return self._provider.make_request(*args)
 
+    def get_blocks(self, start_slot: int, end_slot: Optional[int] = None) -> types.RPCResponse:
+        """Returns a list of confirmed blocks.
+
+        :param start_slot: Start slot, as u64 integer.
+        :param end_slot: (optional) End slot, as u64 integer.
+
+        >>> solana_client = Client("http://localhost:8899")
+        >>> solana_client.get_blocks(5, 10) # doctest: +SKIP
+        {'jsonrpc': '2.0', 'result': [5, 6, 7, 8, 9, 10], 'id': 1}
+        """
+        args = self._get_blocks_args(start_slot, end_slot)
+        return self._provider.make_request(*args)
+
     def get_confirmed_signature_for_address2(
         self,
         account: Union[str, Keypair, PublicKey],
@@ -365,6 +437,40 @@ class Client(_ClientCore):  # pylint: disable=too-many-public-methods
         args = self._get_confirmed_transaction_args(tx_sig, encoding)
         return self._provider.make_request(*args)
 
+    def get_transaction(self, tx_sig: str, encoding: str = "json") -> types.RPCResponse:
+        """Returns transaction details for a confirmed transaction.
+
+        :param tx_sig: Transaction signature as base-58 encoded string N encoding attempts to use program-specific
+            instruction parsers to return more human-readable and explicit data in the
+            `transaction.message.instructions` list.
+        :param encoding: (optional) Encoding for the returned Transaction, either "json", "jsonParsed",
+            "base58" (slow), or "base64". If parameter not provided, the default encoding is JSON.
+
+        >>> solana_client = Client("http://localhost:8899")
+        >>> solana_client.get_transaction("3PtGYH77LhhQqTXP4SmDVJ85hmDieWsgXCUbn14v7gYyVYPjZzygUQhTk3bSTYnfA48vCM1rmWY7zWL3j1EVKmEy") # doctest: +SKIP
+        {'jsonrpc': '2.0',
+         'result': {'meta': {'err': None,
+           'fee': 5000, 'rewards': [],
+           'postBalances': [498449233720610510, 1000001001987940, 1],
+           'preBalances': [498449233721615510, 1000001000987940, 1],
+           'status': {'Ok': None}},
+          'slot': 1659335,
+          'transaction': {'message': {'accountKeys': ['9B5XszUGdMaxCZ7uSQhPzdks5ZQSmWxrmzCSvtJ6Ns6g',
+             '2KW2XRd9kwqet15Aha2oK3tYvd3nWbTFH1MBiRAv1BE1',
+             '11111111111111111111111111111111'],
+            'header': {'numReadonlySignedAccounts': 0,
+             'numReadonlyUnsignedAccounts': 1,
+             'numRequiredSignatures': 1},
+            'instructions': [{'accounts': [0, 1],
+              'data': '3Bxs4Bc3VYuGVB19',
+              'programIdIndex': 2}],
+            'recentBlockhash': 'FwcsKNptGtMLccXAA9YgnivVFK95mKzECLT1DNPi3SDr'},
+           'signatures': ['3PtGYH77LhhQqTXP4SmDVJ85hmDieWsgXCUbn14v7gYyVYPjZzygUQhTk3bSTYnfA48vCM1rmWY7zWL3j1EVKmEy']}},
+         'id': 4}
+        """  # noqa: E501 # pylint: disable=line-too-long
+        args = self._get_transaction_args(tx_sig, encoding)
+        return self._provider.make_request(*args)
+
     def get_epoch_info(self, commitment: Optional[Commitment] = None) -> types.RPCResponse:
         """Returns information about the current epoch.
 
